from django.db import models


class Guild(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=200)
    tag = models.CharField(max_length=10)
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return f"{self.name} [{self.tag}]"

    class Meta:
        verbose_name = "Guild"
        verbose_name_plural = "Guilds"


class Player(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=200)
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = "Player"
        verbose_name_plural = "Players"


class PlayerGuild(models.Model):
    id = models.AutoField(primary_key=True)
    player = models.ForeignKey(Player, on_delete=models.CASCADE, related_name="guilds")
    guild = models.ForeignKey(Guild, on_delete=models.CASCADE, related_name="players")
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return f"{self.player} - {self.guild}"

    class Meta:
        verbose_name = "Player Guild"
        verbose_name_plural = "Player Guilds"


class Game(models.Model):
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=200)
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = "Game"
        verbose_name_plural = "Games"


class PlayerGameProfile(models.Model):
    id = models.AutoField(primary_key=True)
    player = models.ForeignKey(
        Player, on_delete=models.CASCADE, related_name="game_profiles"
    )
    game = models.ForeignKey(
        Game, on_delete=models.CASCADE, related_name="player_profiles"
    )
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return f"{self.player} - {self.game}"

    class Meta:
        verbose_name = "Player Game Profile"
        verbose_name_plural = "Player Game Profiles"


class WowProfile(models.Model):
    id = models.AutoField(primary_key=True)
    player_game_profile = models.OneToOneField(
        PlayerGameProfile, on_delete=models.CASCADE, related_name="wow_profile"
    )
    level = models.IntegerField()
    class_name = models.CharField(max_length=200)
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return f"{self.player_game_profile.player} - {self.player_game_profile.game}"

    class Meta:
        verbose_name = "WoW Profile"
        verbose_name_plural = "WoW Profiles"


class ValorantProfile(models.Model):
    id = models.AutoField(primary_key=True)
    player_game_profile = models.OneToOneField(
        PlayerGameProfile, on_delete=models.CASCADE, related_name="valorant_profile"
    )
    rank = models.CharField(max_length=200)
    creation_date = models.DateTimeField("date created", auto_now_add=True)

    def __str__(self):
        return f"{self.player_game_profile.player} - {self.player_game_profile.game}"

    class Meta:
        verbose_name = "Valorant Profile"
        verbose_name_plural = "Valorant Profiles"
